@@ -1,12 +1,12 @@
-# Copyrights 2001-2011 by Mark Overmeer.
+# Copyrights 2001-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 package Mail::Box::Thread::Node;
 use vars '$VERSION';
-$VERSION = '2.099';
+$VERSION = '2.108';
 
 use base 'Mail::Reporter';
 
@@ -77,21 +77,15 @@ sub addMessage($)
     $message;
 }
 
-#-------------------------------------------
-
 
 sub isDummy()
 {   my $self = shift;
     !defined $self->{MBTN_messages} || $self->{MBTN_messages}[0]->isDummy;
 }
 
-#-------------------------------------------
-
 
 sub messageId() { shift->{MBTN_msgid} }
 
-#-------------------------------------------
-
 
 sub expand(;$)
 {   my $self = shift;
@@ -191,7 +185,7 @@ sub sortedFollowUps()
 
 sub threadToString(;$$$)   # two undocumented parameters for layout args
 {   my $self    = shift;
-    my $code    = shift || sub {shift->head->get('subject')};
+    my $code    = shift || sub {shift->head->study('subject')};
     my ($first, $other) = (shift || '', shift || '');
     my $message = $self->message;
     my @follows = $self->sortedFollowUps;
@@ -265,8 +259,6 @@ sub endTimeEstimate()
     $latest;
 }
 
-#-------------------------------------------
-
 
 sub recurse($)
 {   my ($self, $code) = @_;
@@ -279,8 +271,6 @@ sub recurse($)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub totalSize()
 {   my $self  = shift;
@@ -296,8 +286,6 @@ sub totalSize()
     $total;
 }
 
-#-------------------------------------------
-
 
 sub numberOfMessages()
 {   my $self  = shift;
@@ -308,8 +296,6 @@ sub numberOfMessages()
 
 sub nrMessages() {shift->numberOfMessages}  # compatibility
 
-#-------------------------------------------
-
 
 sub threadMessages()
 {   my $self = shift;
@@ -326,8 +312,6 @@ sub threadMessages()
 }
 
 
-#-------------------------------------------
-
 
 sub ids()
 {   my $self = shift;
